@@ -21,10 +21,27 @@ plot.roc <- function(x, ...) {
   UseMethod("plot.roc")
 }
 
-plot.roc.formula <- function(x, data, ...) {
-  roc <- roc(x, data, plot=TRUE, ...)
-  roc$call <- match.call()
-  invisible(roc)
+plot.roc.formula <- function(x, data, subset, na.action, ...) {
+	# Get the data. Use standard code from survival::coxph as suggested by Terry Therneau
+	Call <- match.call()
+	indx <- match(c("x", "data", "weights", "subset", "na.action"), names(Call), nomatch=0)
+	if (indx[1] == 0) {
+		stop("A formula is required as 'x' argument")
+	}
+	# Keep the standard arguments and run them in model.frame
+	temp <- Call[c(1,indx)]  
+	temp[[1]] <- as.name('model.frame')
+	names(temp)[2] <- "formula"
+	m <- eval(temp, parent.frame())
+	
+	if (!is.null(model.weights(m))) stop("weights are not supported")
+	
+	response <- model.response(m)
+	predictor <- m[[attr(terms(x), "term.labels")]]
+	
+	roc <- roc(response, predictor, plot=TRUE, ...)
+	roc$call <- match.call()
+	invisible(roc)
 }
 
 plot.roc.default <- function(x, predictor, ...) {
@@ -127,7 +144,7 @@ plot.roc.roc <- function(x,
   if (print.auc & is.null(print.auc.pattern)) {
     print.auc.pattern <- ifelse(identical(partial.auc, FALSE), "AUC: ", "Partial AUC: ")
     print.auc.pattern <- paste(print.auc.pattern, ifelse(percent, "%.1f%%", "%.3f"), sep="")
-    if (ci && class(x$ci) == "ci.auc")
+    if (ci && methods::is(x$ci, "ci.auc"))
       print.auc.pattern <- paste(print.auc.pattern, " (", ifelse(percent, "%.1f%%", "%.3f"), "\u2013", ifelse(percent, "%.1f%%", "%.3f"), ")",sep="")
   }
     
@@ -190,7 +207,7 @@ plot.roc.roc <- function(x,
     suppressWarnings(polygon(map.x, map.y, col=max.auc.polygon.col, lty=max.auc.polygon.lty, border=max.auc.polygon.border, density=max.auc.polygon.density, angle=max.auc.polygon.angle, ...))
   }
   # Plot the ci shape
-  if (ci && class(x$ci) != "ci.auc") {
+  if (ci && ! methods::is(x$ci, "ci.auc")) {
     ci.type <- match.arg(ci.type)
     if (ci.type=="shape")
       plot(x$ci, type="shape", col=ci.col, no.roc=TRUE, ...)
@@ -251,7 +268,7 @@ plot.roc.roc <- function(x,
   # Actually plot the ROC curve
   suppressWarnings(lines(sp, se, type=type, lwd=lwd, col=col, lty=lty, ...))
   # Plot the ci bars
-  if (ci && class(x$ci) != "ci.auc") {
+  if (ci && !methods::is(x$ci, "ci.auc")) {
     if (ci.type=="bars")
       plot(x$ci, type="bars", col=ci.col, ...)
   }
@@ -260,14 +277,14 @@ plot.roc.roc <- function(x,
     print.thres <- "best"
   if (is.character(print.thres))
     print.thres <- match.arg(print.thres, c("no", "all", "local maximas", "best"))
-  if (class(x) == "smooth.roc") {
+  if (methods::is(x, "smooth.roc")) {
     if (is.numeric(print.thres))
       stop("Numeric 'print.thres' unsupported on a smoothed ROC plot.")
     else if (print.thres == "all" || print.thres == "local maximas")
       stop("'all' and 'local maximas' 'print.thres' unsupported on a smoothed ROC plot.") 
     else if (print.thres == "best") {
       co <- coords(x, print.thres, best.method=print.thres.best.method, best.weights=print.thres.best.weights)
-      if (class(co) == "matrix") {
+      if (methods::is(co, "matrix")) {
         suppressWarnings(points(co[2,], co[1,], pch=print.thres.pch, cex=print.thres.cex, col=print.thres.col, ...))
         suppressWarnings(text(co[2,], co[1,], sprintf(print.thres.pattern, NA, co[2,], co[1,]), adj=print.thres.adj, cex=print.thres.pattern.cex, col=print.thres.col, ...))
       }
@@ -281,7 +298,7 @@ plot.roc.roc <- function(x,
     if (is.character(print.thres) && print.thres == "no") {} # do nothing
     else {
       co <- coords(x, print.thres, best.method=print.thres.best.method, best.weights=print.thres.best.weights)
-      if (class(co) == "matrix") {
+      if (methods::is(co, "matrix")) {
         suppressWarnings(points(co[2,], co[3,], pch=print.thres.pch, cex=print.thres.cex, col=print.thres.col, ...))
         suppressWarnings(text(co[2,], co[3,], sprintf(print.thres.pattern, co[1,], co[2,], co[3,]), adj=print.thres.adj, cex=print.thres.pattern.cex, col=print.thres.col, ...))
       }
@@ -294,7 +311,7 @@ plot.roc.roc <- function(x,
 
   # Print the AUC on the plot
   if (print.auc) {
-    if (ci && class(x$ci) == "ci.auc") {
+    if (ci && methods::is(x$ci, "ci.auc")) {
       labels <- sprintf(print.auc.pattern, x$auc, x$ci[1], x$ci[3])
       suppressWarnings(text(print.auc.x, print.auc.y, labels, adj=print.auc.adj, cex=print.auc.cex, col=print.auc.col, ...))
     }
